@@ -27,6 +27,20 @@ my $default = {
         sunset => [ 'white', '#f9d87b', '#936d1a', '#bf3136', '#94148e', '#c3baee', '#1d1d7c', '#111111', 'black' ],
     },
     color => {
+        white            => [ 255, 255, 255],
+        black            => [   0,   0,   0],
+        red              => [ 255,   0,   0],
+        green            => [   0, 128,   0],
+        blue             => [   0,   0, 255],
+        yellow           => [ 255, 255,   0],
+        purple           => [ 128,   0, 128],
+        pink             => [ 255, 192, 203],
+        peach            => [ 250, 125, 125],
+        plum             => [ 221, 160, 221],
+        mauve            => [ 200, 125, 125],
+        brown            => [ 165,  42,  42],
+        grey             => [ 225, 225, 225],
+        aliceblue        => [ 240, 248, 255],
         bright_blue      => [  98, 156, 249],
         marsala          => [ 149,  82,  81],
         radiandorchid    => [ 181, 101, 167],
