@@ -111,11 +111,11 @@ sub new {
 
 sub init {
     my ( $self ) = @_;
-    $self->set_data ({ color => 1,      select => 8,  repeat => 4, group => 1,
-                       gradient => 8, dynamics => 0,  smooth => 0, substeps => 0 } );
+    $self->set_settings ({ color => 1,      select => 8,  repeat => 1, group => 1,
+                       gradient => 10, dynamics => 0,  smooth => 0, substeps => 0 } );
 }
 
-sub get_data {
+sub get_settings {
     my ( $self ) = @_;
     {
         color   => int $self->{'color'}->GetValue,
@@ -129,7 +129,7 @@ sub get_data {
     }
 }
 
-sub set_data {
+sub set_settings {
     my ( $self, $data ) = @_;
     return 0 unless ref $data eq 'HASH' and exists $data->{'select'};
     $self->PauseCallBack();
