@@ -6,7 +6,7 @@ package App::GUI::Juliagraph::Frame::Part::Board;
 use base qw/Wx::Panel/;
 
 use Graphics::Toolkit::Color qw/color/;
-use Benchmark;
+#use Benchmark;
 
 use constant SKETCH_FACTOR => 4;
 
@@ -72,6 +72,46 @@ sub set_settings {
 
 sub paint {
     my( $self, $dc, $width, $height ) = @_;
+    #my $t0 = Benchmark->new();
+    my %factor = ();
+    my $max_exp;
+    for my $mnr (1 .. 4){
+        my $settings = $self->{'data'}{'monomial_'.$mnr};
+        next unless $settings->{'active'};
+        my $f = $settings->{'use_factor'} ? [$settings->{'factor_r'}, $settings->{'factor_i'}] : [1,1];
+        if (exists $factor{$settings->{'exponent'}}) {
+            $factor{ $settings->{'exponent'} }[0] *= $f->[0];
+            $factor{ $settings->{'exponent'} }[1] *= $f->[1];
+        } else { $factor{ $settings->{'exponent'} } = $f }
+        $max_exp = $settings->{'exponent'} unless defined $max_exp;
+        $max_exp = $settings->{'exponent'} if $max_exp < $settings->{'exponent'};
+    }
+    $max_exp = 0 unless defined $max_exp;
+
+    my $zoom_size = 4 * (10** (-$self->{'data'}{'constraints'}{'zoom'}));
+    my $stop = $self->{'data'}{'constraints'}{'stop_value'};
+    my $x_delta = $zoom_size;
+    my $x_delta_step = $x_delta / $self->{'size'}{'x'};
+    my $x_min = $self->{'data'}{'constraints'}{'pos_x'} - ($x_delta / 2);
+    my $y_delta = $zoom_size;
+    my $y_delta_step = $y_delta / $self->{'size'}{'y'};
+    my $y_min = $self->{'data'}{'constraints'}{'pos_y'} - ($y_delta / 2);
+    my $const_a = ($self->{'data'}{'constraints'}{'constant'} eq 'constant') ? $self->{'data'}{'constraints'}{'const_a'} : 0;
+    my $const_b = ($self->{'data'}{'constraints'}{'constant'} eq 'constant') ? $self->{'data'}{'constraints'}{'const_b'} : 0;
+    $const_a *= $factor{0}[0] if exists $factor{0} and $factor{0}[0];
+    $const_b *= $factor{0}[1] if exists $factor{0} and $factor{0}[1];
+    my $position = $self->{'data'}{'constraints'}{'position'};
+    $position = substr($position, 7) if substr($position, 0, 7) eq 'degree ';
+    if ($position =~ /\d/){
+        $max_exp = $position if $max_exp < $position;
+    }
+
+    my $metric = { '|var|' => '($x*$x) + ($y*$y)', '|x|' => 'abs($x)',         '|y|' => 'abs($y)',
+                   '|x+y|' => 'abs($x+$y)',    '|x|+|y|' => 'abs($x)+abs($y)', 'x+y' => '$x+$y',
+                    'x*y'  => '$x*$y',           '|x*y|' => 'abs($x*$y)',
+                     'x-y' => '$x-$y',             'y-x' => '$y-$x',
+    };
+
     my $background_color = Wx::Colour->new( 255, 255, 255 );
     $dc->SetBackground( Wx::Brush->new( $background_color, &Wx::wxBRUSHSTYLE_SOLID ) );
     $dc->Clear();
@@ -93,7 +133,7 @@ sub paint {
         }
     } else {
             @color = map {[$_->values]} color('white')->gradient( to => 'black',
-                                                               steps => $self->{'data'}{'mapping'}{'select'} * $self->{'data'}{'mapping'}{'gradient'},
+                                                               steps => $self->{'data'}{'mapping'}{'select'} * ($self->{'data'}{'mapping'}{'gradient'}+2),
                                                              dynamic => $self->{'data'}{'mapping'}{'dynamics'},
                                                                 );
     }
@@ -112,29 +152,9 @@ sub paint {
         $progress->add_percentage( $_ / $#color * 100, $color[$_] ) for 0 .. $#color;
         $progress->full;
     }
+    $color[$_] = [0,0,0] for $colors .. $self->{'data'}{'constraints'}{'stop_value'}; # background color
 
 
-    $color[$_] = [0,0,0] for $colors .. $self->{'data'}{'form'}{'stop_value'}; # background color
-
-
-    my $zoom_size = 4 * (10** (-$self->{'data'}{'form'}{'zoom'}));
-    my $stop = $self->{'data'}{'form'}{'stop_value'};
-    my $const_a = $self->{'data'}{'form'}{'const_a'};
-    my $const_b = $self->{'data'}{'form'}{'const_b'};
-    my $var_c = $self->{'data'}{'form'}{'var_c'};
-    my $var_d = $self->{'data'}{'form'}{'var_d'};
-    my $x_delta = $zoom_size;
-    my $x_delta_step = $x_delta / $self->{'size'}{'x'};
-    my $x_min = $self->{'data'}{'form'}{'pos_x'} - ($x_delta / 2);
-    my $y_delta = $zoom_size;
-    my $y_delta_step = $y_delta / $self->{'size'}{'y'};
-    my $y_min = $self->{'data'}{'form'}{'pos_y'} - ($y_delta / 2);
-
-    my $metric = { '|var|' => '($x*$x) + ($y*$y)', '|x|' => 'abs($x)', '|y|' => 'abs($y)',
-                   '|x+y|' => 'abs($x+$y)',    '|x|+|y|' => 'abs($x)+abs($y)', 'x+y' => '$x+$y',
-                    'x*y'  => '$x*$y',           '|x*y|' => 'abs($x*$y)',
-                    'x-y' => '$x-$y', 'y-x' => '$y-$x',
-    };
     if ($self->{'flag'}{'sketch'}){
         $x_delta_step *= SKETCH_FACTOR;
         $y_delta_step *= SKETCH_FACTOR;
@@ -142,9 +162,8 @@ sub paint {
         $stop = 100 if $stop > 100;
     }
 
-    my $t0 = Benchmark->new();
     my $img = Wx::Image->new($self->{'size'}{'x'},$self->{'size'}{'y'});
-    my ($x_const, $y_const, $x, $y, $x_old, $y_old);
+    my ($x_const, $y_const, $x, $y, $x_old, $y_old, $x_pot, $y_pot);
 
     my $code = 'my ($x_num, $x_pix) = ($x_min, 0);'."\n";
     $code .= $self->{'flag'}{'sketch'}
@@ -154,20 +173,43 @@ sub paint {
     $code .= $self->{'flag'}{'sketch'}
            ? '  for (0 .. $self->{size}{y} / SKETCH_FACTOR){'."\n"
            : '  for (0 .. $self->{size}{y}){'."\n";
-    $code .= ($self->{'data'}{'form'}{'type'} eq 'Julia')
-           ? '    ($x, $y) = ($x_num, $y_num);'."\n".
-             '    ($x_const, $y_const) = ($const_a, $const_b);'."\n"
-           : '    ($x, $y) = ($const_a, $const_b);'."\n".
-             '    ($x_const, $y_const) = ($x_num, $y_num);'."\n";
+
+    my $x_start_value = ($self->{'data'}{'constraints'}{'constant'} eq 'start value') ? $self->{'data'}{'constraints'}{'const_a'} : 0;
+    my $y_start_value = ($self->{'data'}{'constraints'}{'constant'} eq 'start value') ? $self->{'data'}{'constraints'}{'const_b'} : 0;
+
+    if ($position eq 'start value'){
+        $x_start_value = $x_start_value ? $x_start_value . ' + $x_num' : '$x_num';
+        $y_start_value = $y_start_value ? $y_start_value . ' + $y_num' : '$y_num';
+    }
+
+    $code .= '    $x = '.$x_start_value.';'."\n";
+    $code .= '    $y = '.$y_start_value.';'."\n";
     $code .= '    for my $i (0 .. $colors){'."\n";
-    $code .= '      $x_old = $x;'."\n";
-    $code .= '      $y_old = $y;'."\n";
-    $code .= '      ($x, $y) = (($x * $x_old) - ($y * $y_old), ($x * $y_old) + ($x_old * $y));'."\n" for 2 .. $self->{'data'}{'form'}{'exp'};
-    $code .= '      $x += $x_old * $var_c;'."\n" if $var_c;
-    $code .= '      $y += $y_old * $var_d;'."\n" if $var_d;
-    $code .= '      $x += $x_const;'."\n";
-    $code .= '      $y += $y_const;'."\n";
-    $code .= '      if ('.$metric->{$self->{'data'}{'form'}{'stop_metric'}}.' > $stop){'."\n";
+    $code .= '      $x_pot = $x_old = $x;'."\n";
+    $code .= '      $y_pot = $y_old = $y;'."\n";
+    $code .= '      $x = '.(($position eq 'constant') ? $const_a.'+ $x_num' : $const_a).';'."\n";
+    $code .= '      $y = '.(($position eq 'constant') ? $const_b.'+ $y_num' : $const_b).';'."\n";
+
+    for my $exponent (2 .. $max_exp){
+        $code .= '      ($x_pot, $y_pot) = (($x_pot * $x_old) - ($y_pot * $y_old), ($x_pot * $y_old) + ($x_old * $y_pot));'."\n";
+        my $x_factor = (exists $factor{$exponent} and $factor{$exponent}[0]) ? ' * '.$factor{$exponent}[0] : '';
+        my $y_factor = (exists $factor{$exponent} and $factor{$exponent}[1]) ? ' * '.$factor{$exponent}[1] : '';
+        if ($position eq $exponent){
+            $x_factor .= ' * $x_num';
+            $y_factor .= ' * $y_num';
+        }
+        $code .= '      $x += $x_pot '.$x_factor.';'."\n" if $x_factor;
+        $code .= '      $y += $y_pot '.$y_factor.';'."\n" if $y_factor;
+    }
+    my $x_linear = (exists $factor{1} and $factor{1}[0]) ? ' * '.$factor{1}[0] : '';
+    my $y_linear = (exists $factor{1} and $factor{1}[1]) ? ' * '.$factor{1}[1] : '';
+    if ($position eq 1){
+        $x_linear .= ' * $x_num';
+        $y_linear .= ' * $y_num';
+    }
+    $code .= '      $x += $x_old '.$x_linear.';'."\n" if $x_linear;
+    $code .= '      $y += $y_old '.$y_linear.';'."\n" if $y_linear;
+    $code .= '      if ('.$metric->{$self->{'data'}{'constraints'}{'stop_metric'}}.' > $stop){'."\n";
     $code .= '        $img->SetRGB( $x_pix,   $y_pix,   @{$color[$i]});'."\n";
     $code .= '        $img->SetRGB( $x_pix,   $y_pix+1, @{$color[$i]});'."\n".
              '        $img->SetRGB( $x_pix+1, $y_pix,   @{$color[$i]});'."\n".
@@ -186,10 +228,12 @@ sub paint {
            : '  $x_pix ++;'."\n";
     $code .= '}'."\n";
 
+    #say "compile:",timestr(timediff(Benchmark->new, $t0));
+    #$t0 = Benchmark->new();
     eval $code; # say $code;
     die "bad iter code - $@ :\n$code" if $@; # say "comp: ",timestr( timediff( Benchmark->new(), $t) );
 
-    say "compute:",timestr(timediff(Benchmark->new, $t0));
+    #say "run:",timestr(timediff(Benchmark->new, $t0));
 
     $dc->DrawBitmap( Wx::Bitmap->new( $img ), 0, 0, 0 );
     $self->{'image'} = $img unless $self->{'flag'}{'sketch'};
